/**
 * 
 */
package de.mpc.prolic.model;

import java.util.ArrayList;
import java.util.Collections;



/**
 * This Class stores a sorted set of related biomolecule groups obtained from comparison (i.e. the BiomleculeGroupList represents 
 * either an intersection or the set differences)
 * @author Michael Kohl
 *
 */
public class BiomoleculeGroupList implements Comparable<Object> {

	/*******************************************************************************
	 * Members 
	 ******************************************************************************/
	private ArrayList <BiomoleculeGroup>bgList;					//List of of biomolecule groups 
	private String listIdentfier;								//Identifier of the biomolecule group list. Unique value, because the names of the original 
																//lists are unique.
	/*******************************************************************************
	 * Constructors
	 ******************************************************************************/
	/**
	 * Empty constructor
	 */
	public BiomoleculeGroupList() {
		bgList=new ArrayList<BiomoleculeGroup>();
	}
	
	/**
	 * 
	 * @param aPG
	 */
	
	/**
	 * Adds a biomolecule group to the arrayList of biomolecule groups. The resulting set is sorted. 
	 * @param aBG
	 */
		public void addBiomoleculeGroup(BiomoleculeGroup aBG){
			bgList.add(aBG);
			sortBiomoleculeGroups();
		}
		
	/**
	 * Adding all at once the biomolecule groups that belong to this BiomleculeGroupList. The resulting set is sorted. 
	 * @param bgList_
	 */
		public void addBiomoleculeGroups(ArrayList<BiomoleculeGroup> bgList_){
			this.bgList = bgList_;
			sortBiomoleculeGroups();
		}
		
	/**
	 * Sorts all BiomoleculeGroup
	 */
		public void sortBiomoleculeGroups(){
			Collections.sort(bgList);
		}
		
		
		@Override
	/**
	 * Supports the comparison of two instances of BiomoleculeGroupList with respect to their identifiers
	 */
		public int compareTo(Object o) {
			BiomoleculeGroupList bgl = (BiomoleculeGroupList)o;
			return this.getListIdentifier().compareTo(bgl.getListIdentifier());
		}
		
	/*******************************************************************************
	 * Setter and Getter
	 ******************************************************************************/
	
		/**
		 * Retrieves a list of biomolecule groups (i.e. a representation of related biomolecules, which are member of either a set difference or
		 * an intersection considering a set of compared biomolecule lists)
		 * @return a list of biomolecule groups that are either part off an intersection or a set difference.
		 */
		public ArrayList<BiomoleculeGroup> getBgList(){
			return this.bgList;
		}

		/**
		 * Stores a list of biomolecule groups (i.e. a representation of related biomolecules, which are member of either a set difference or
		 * an intersection considering a set of compared biomolecule lists)
		 * @param bgList_
		 */
		public void setBgList(ArrayList<BiomoleculeGroup> bgList_){
			this.bgList=bgList_;
		}
			

		/**
		 * The method retrieves a string identifier for the list of Biomolecule groups
		 * @return a string identifier for the list of Biomolecule groups
		 */
		public String getListIdentifier(){
			return this.listIdentfier;
		}

		/**
		 * Stores a string identifier for the list of Biomolecule groups
		 * @param listIdentifier_
		 */
		public void setListIdentifier(String listIdentifier_){
			this.listIdentfier=listIdentifier_;
		}


}
