/**
 * 
 */
package de.mpc.prolic.model;

import java.util.ArrayList;

/**
 * @author Michael Kohl
 * This class stores the information related with the basic ProLiC input, which is obtained from a distinct file, which gives a list of
 * biomolecules. Each file specified for comparison is represented by a single instance of BiomoleculeList 
 */
public class BiomoleculeList {

	/*******************************************************************************
	 * Members
	 ******************************************************************************/	
	private String listName;							//The name of the BiomoleculeList, i.e. the name of the related input file without file extension.
	private ArrayList<Biomolecule> biomolecules; 		//The Biomolecules generated from reading the input file
	/*******************************************************************************
	 * Constructors
	 ******************************************************************************/
	/**
	 * Empty constructor
	 */
	public BiomoleculeList() {
		biomolecules=new ArrayList<Biomolecule>();
	}
	
	/**
	 * Generating a BiomoleculeList instance along with a collection of the related biomolecules.
	 * @param biomolecules_
	 */
	public BiomoleculeList(ArrayList<Biomolecule> biomolecules_) {
		biomolecules=biomolecules_;
	}
	
	/**
	 * Generating a BiomoleculeList instance along with a collection of the related biomolecules and the list identifier.
	 * @param biomolecules_
	 */
	public BiomoleculeList(ArrayList<Biomolecule> biomolecules_, String listName_) {
		biomolecules=biomolecules_;
		listName=listName_;
	}
	
	/**
	 * Adds a Biomolecule to the existing ArrayList biomolecules.
	 */
	public void addBiomolecules(Biomolecule aBiomolecule){
		this.biomolecules.add(aBiomolecule);
	}

	/*******************************************************************************
	 * Setter and Getter
	 ******************************************************************************/
	public String getListName(){
		return this.listName;
	}
	
	public void setListName(String listName_){
		this.listName=listName_;
	}
	
	public ArrayList<Biomolecule> getBiomolecules(){
		return this.biomolecules;
	}
	
	public void setBiomolecules(ArrayList<Biomolecule> biomolecules_){
		this.biomolecules=biomolecules_;
	}
}
